.. emsuite documentation master file, created by
   sphinx-quickstart on Wed Jan 14 18:18:27 2026.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

emsuite
=======

**emsuite** calculates electrostatic properties of chemical systems, presenting them in a visually intuitive manner.

.. toctree::
   :maxdepth: 1
   :caption: Getting Started
   :hidden:

   installation

.. toctree::
   :maxdepth: 2
   :caption: Modules
   :hidden:

   Tuning <tuning/index>
   Potential <potential/index>
   Combined <combined/index>

